@@ -186,7 +186,6 @@ class MWCShellConfig(SetupTask):
             fh.write(f"\n# MAKING WITH CODE\n")
             fh.write(f'export PATH="{mwcpath}:$PATH"\n')
             fh.write(f"source {get_mwc_rc_path()}\n")
-        self.mwc_rc_file.write_text("")
         
     def platform_rc_file(self):
         shell = get_shell_name()
@@ -227,23 +226,6 @@ class InstallXCode(SetupTask):
         click.echo(address(msg))
         run("xcode-select --install", shell=True, check=True)
 
-# For Isaak, this installed Poetry but didn't add it to the path. Maybe we should use homebrew instead?
-class InstallPoetry(SetupTask):
-    description = "Install poetry"
-
-    def is_complete(self):
-        return self.executable_on_path("poetry")
-
-    def run_task(self):
-        shell = get_shell_name()
-        click.echo(address("Installing poetry..."))
-        run("curl -sSL https://install.python-poetry.org | python3 -", shell=True, check=True)
-        click.echo(address("Installing poetry tab completions..."))
-        if shell == "bash":
-            run("poetry completions bash > /etc/bash_completion.d/poetry", shell=True, check=True)
-        if shell == "zsh":
-            run("poetry completions zsh > ~/.zfunc/_poetry", shell=True, check=True)
-
 class WriteShellConfig(SetupTask):
     description = "Write the MWC shell configuration file ~/.mwc_rc"
 
@@ -299,6 +281,9 @@ class InstallPackage(SetupTask):
 class InstallPython3(InstallPackage):
     package_name = brew_name = apt_name = "python3"
 
+class InstallPoetry(InstallPackage):
+    package_name = brew_name = apt_name = "poetry"
+
 class InstallGit(InstallPackage):
     package_name = brew_name = apt_name = "git"
 
